@@ -1,19 +1,20 @@
 #!/usr/bin/env python3
 """
-Functions for enumerating and contrasting the available colors and fonts.
+Functions for displaying colors and fonts.
 """
 import os
-import numpy as np
+
 import cycler
-import matplotlib.font_manager as mfonts
 import matplotlib.colors as mcolors
-from . import ui
-from . import constructor
+import matplotlib.font_manager as mfonts
+import numpy as np
+
 from . import colors as pcolors
-from .utils import to_rgb, to_xyz
-from .config import rc, _get_data_paths, BASE_COLORS, XKCD_COLORS, OPEN_COLORS
+from . import constructor, ui
+from .config import _get_data_folders, rc
 from .internals import ic  # noqa: F401
-from .internals import docstring, _not_none
+from .internals import _not_none, _snippet_manager, warnings
+from .utils import to_rgb, to_xyz
 
 __all__ = [
     'show_cmaps',
@@ -25,14 +26,15 @@ __all__ = [
 ]
 
 COLORS_TABLE = {
-    'base': list(BASE_COLORS),
-    'opencolor': list(OPEN_COLORS),
-    'xkcd': list(XKCD_COLORS),
-    'css4': list(mcolors.CSS4_COLORS),
+    # NOTE: Just want the names but point to the dictionaries because they
+    # get filled after this module is imported in __init__.
+    'base': pcolors.COLORS_BASE,
+    'opencolor': pcolors.COLORS_OPEN,
+    'xkcd': pcolors.COLORS_XKCD,
+    'css4': mcolors.CSS4_COLORS,
 }
 
 CMAPS_TABLE = {
-    # Nice colormaps that get shown by default
     # NOTE: No longer rename colorbrewer greys map, just redirect 'grays'
     # to 'greys' in colormap database.
     'Grayscale': (  # assorted origin, but they belong together
@@ -45,7 +47,7 @@ CMAPS_TABLE = {
         'twilight',
     ),
     'Seaborn sequential': (
-        'Rocket', 'Mako',
+        'Rocket', 'Flare', 'Mako', 'Crest',
     ),
     'Seaborn diverging': (
         'IceFire', 'Vlag',
@@ -53,18 +55,21 @@ CMAPS_TABLE = {
     'ProPlot sequential': (
         'Fire',
         'Stellar',
-        'Boreal',
-        'Marine',
-        'Dusk',
         'Glacial',
+        'Dusk',
+        'Marine',
+        'Boreal',
         'Sunrise',
         'Sunset',
     ),
     'ProPlot diverging': (
         'Div', 'NegPos', 'DryWet',
     ),
+    'Other sequential': (
+        'cubehelix', 'turbo'
+    ),
     'Other diverging': (
-        'ColdHot', 'CoolWarm', 'BR',
+        'BR', 'ColdHot', 'CoolWarm',
     ),
     'cmOcean sequential': (
         'Oxy', 'Thermal', 'Dense', 'Ice', 'Haline',
@@ -99,24 +104,28 @@ CMAPS_TABLE = {
         'RdBu', 'RdYlBu', 'RdYlGn',
     ),
     'SciVisColor blues': (
-        'Blue1', 'Blue2', 'Blue3', 'Blue4', 'Blue5',
-        'Blue6', 'Blue7', 'Blue8', 'Blue9', 'Blue10', 'Blue11',
+        'Blues1', 'Blues2', 'Blues3', 'Blues4', 'Blues5',
+        'Blues6', 'Blues7', 'Blues8', 'Blues9', 'Blues10', 'Blues11',
     ),
     'SciVisColor greens': (
-        'Green1', 'Green2', 'Green3', 'Green4', 'Green5',
-        'Green6', 'Green7', 'Green8',
+        'Greens1', 'Greens2', 'Greens3', 'Greens4', 'Greens5',
+        'Greens6', 'Greens7', 'Greens8',
+    ),
+    'SciVisColor yellows': (
+        'Yellows1', 'Yellows2', 'Yellows3', 'Yellows4',
     ),
     'SciVisColor oranges': (
-        'Orange1', 'Orange2', 'Orange3', 'Orange4', 'Orange5',
-        'Orange6', 'Orange7', 'Orange8',
+        'Oranges1', 'Oranges2', 'Oranges3', 'Oranges4',
     ),
     'SciVisColor browns': (
-        'Brown1', 'Brown2', 'Brown3', 'Brown4', 'Brown5',
-        'Brown6', 'Brown7', 'Brown8', 'Brown9',
+        'Browns1', 'Browns2', 'Browns3', 'Browns4', 'Browns5',
+        'Browns6', 'Browns7', 'Browns8', 'Browns9',
     ),
-    'SciVisColor reds and purples': (
-        'RedPurple1', 'RedPurple2', 'RedPurple3', 'RedPurple4',
-        'RedPurple5', 'RedPurple6', 'RedPurple7', 'RedPurple8',
+    'SciVisColor reds': (
+        'Reds1', 'Reds2', 'Reds3', 'Reds4', 'Reds5',
+    ),
+    'SciVisColor purples': (
+        'Purples1', 'Purples2', 'Purples3',
     ),
     # Builtin colormaps that re hidden by default. Some are really bad, some
     # are segmented maps that should be cycles, and some are just uninspiring.
@@ -133,7 +142,7 @@ CMAPS_TABLE = {
     ),
     'Other': (
         'binary', 'bwr', 'brg',  # appear to be custom matplotlib
-        'cubehelix', 'Wistia', 'CMRmap',  # individually released
+        'Wistia', 'CMRmap',  # individually released
         'seismic', 'terrain', 'nipy_spectral',  # origin ambiguous
         'tab10', 'tab20', 'tab20b', 'tab20c',  # merged colormap cycles
     )
@@ -159,7 +168,7 @@ CYCLES_TABLE = {
     ),
 }
 
-docstring.snippets['show.colorbars'] = """
+_snippet_manager['show.colorbars'] = """
 length : float or str, optional
     The length of the colorbars. Units are interpreted by
     `~proplot.utils.units`.
@@ -167,115 +176,26 @@ width : float or str, optional
     The width of the colorbars. Units are interpreted by
     `~proplot.utils.units`.
 """
-docstring.snippets['color.categories'] = ', '.join(
+_snippet_manager['color.categories'] = ', '.join(
     f'``{cat!r}``' for cat in COLORS_TABLE
 )
-docstring.snippets['cmap.categories'] = ', '.join(
+_snippet_manager['cmap.categories'] = ', '.join(
     f'``{cat!r}``' for cat in CMAPS_TABLE
 )
-docstring.snippets['cycle.categories'] = ', '.join(
+_snippet_manager['cycle.categories'] = ', '.join(
     f'``{cat!r}``' for cat in CYCLES_TABLE
 )
 
 
-def _draw_bars(
-    cmaps, *, source, unknown='User', categories=None,
-    length=4.0, width=0.2, N=None
-):
-    """
-    Draw colorbars for "colormaps" and "color cycles". This is called by
-    `show_cycles` and `show_cmaps`.
-    """
-    # Translate local names into database of colormaps
-    # NOTE: Custom cmap database raises nice error if colormap name is unknown
-    i = 1
-    database = pcolors.ColormapDatabase({})  # subset to be drawn
-    for cmap in cmaps:
-        if isinstance(cmap, cycler.Cycler):
-            name = getattr(cmap, 'name', '_no_name')
-            cmap = mcolors.ListedColormap(cmap.by_key()['color'], name)
-        elif isinstance(cmap, (list, tuple)):
-            name = '_no_name'
-            cmap = mcolors.ListedColormap(cmap, name)
-        elif isinstance(cmap, mcolors.Colormap):
-            name = cmap.name
-        else:
-            name = cmap
-            cmap = pcolors._cmap_database[cmap]
-        if name in database:
-            name = f'{name}_{i}'  # e.g. _no_name_2
-            i += 1
-        database[name] = cmap
-
-    # Categorize the input names
-    cmapdict = {}
-    names_all = list(map(str.lower, database.keys()))
-    names_known = list(map(str.lower, sum(map(list, source.values()), [])))
-    names_unknown = [name for name in names_all if name not in names_known]
-    if unknown and names_unknown:
-        cmapdict[unknown] = names_unknown
-    for cat, names in source.items():
-        names_cat = [name for name in names if name.lower() in names_all]
-        if names_cat:
-            cmapdict[cat] = names_cat
-
-    # Filter out certain categories
-    if categories is None:
-        categories = source.keys() - {'MATLAB', 'GNUplot', 'GIST', 'Other'}
-    if any(cat not in source for cat in categories):
-        raise ValueError(
-            f'Invalid categories {categories!r}. Options are: '
-            + ', '.join(map(repr, source)) + '.'
-        )
-    for cat in (*cmapdict,):
-        if cat not in categories and cat != unknown:
-            cmapdict.pop(cat)
-
-    # Draw figure
-    naxs = len(cmapdict) + sum(map(len, cmapdict.values()))
-    fig, axs = ui.subplots(
-        nrows=naxs, axwidth=length, axheight=width,
-        share=0, hspace=0.03,
-    )
-    iax = -1
-    nheads = nbars = 0  # for deciding which axes to plot in
-    for cat, names in cmapdict.items():
-        nheads += 1
-        for imap, name in enumerate(names):
-            iax += 1
-            if imap + nheads + nbars > naxs:
-                break
-            ax = axs[iax]
-            if imap == 0:  # allocate this axes for title
-                iax += 1
-                ax.set_visible(False)
-                ax = axs[iax]
-            cmap = database[name]
-            if N is not None:
-                cmap = cmap.copy(N=N)
-            ax.colorbar(
-                cmap, loc='fill',
-                orientation='horizontal', locator='null', linewidth=0
-            )
-            ax.text(
-                0 - (rc['axes.labelpad'] / 72) / length, 0.45, name,
-                ha='right', va='center', transform='axes',
-            )
-            if imap == 0:
-                ax.set_title(cat, weight='bold')
-        nbars += len(names)
-    return fig, axs
-
-
 def show_channels(
     *args, N=100, saturation=True, rgb=False, minhue=0,
-    maxsat=500, width=100, axwidth=1.7
+    maxsat=500, width=100, refwidth=1.7
 ):
     """
     Show how arbitrary colormap(s) vary with respect to the hue, chroma,
     luminance, HSL saturation, and HPL saturation channels, and optionally
     the red, blue and green channels. Adapted from `this example \
-<https://matplotlib.org/3.1.0/tutorials/colors/colormaps.html#lightness-of-matplotlib-colormaps>`__.
+<https://matplotlib.org/stable/tutorials/colors/colormaps.html#lightness-of-matplotlib-colormaps>`__.
 
     Parameters
     ----------
@@ -296,13 +216,18 @@ def show_channels(
         The maximum saturation. Use this to truncate large saturation values.
     width : int, optional
         The width of each colormap line in points.
-    axwidth : int or str, optional
+    refwidth : int or str, optional
         The width of each subplot. Passed to `~proplot.ui.subplots`.
 
     Returns
     -------
     `~proplot.figure.Figure`
         The figure.
+
+    See also
+    --------
+    show_cmaps
+    show_colorspaces
     """
     # Figure and plot
     if not args:
@@ -316,8 +241,8 @@ def show_channels(
         array += [np.array([4, 4, 5, 5, 6, 6]) + 2 * int(saturation)]
         labels += ('Red', 'Green', 'Blue')
     fig, axs = ui.subplots(
-        array=array, span=False, share=1,
-        axwidth=axwidth, axpad='1em',
+        array=array, refwidth=refwidth, wratios=(1.5, 1, 1, 1, 1, 1.5),
+        share='labels', span=False, innerpad=1,
     )
     # Iterate through colormaps
     mc = ms = mp = 0
@@ -361,18 +286,15 @@ def show_channels(
                 for _ in range(3):  # rotate up to 1080 degrees
                     y[y < minhue] += 360
             else:
-                if label == 'Chroma':
-                    mc = max(min(max(mc, max(y)), maxsat), 100)
-                    m = mc
-                elif 'HSL' in label:
-                    ms = max(min(max(ms, max(y)), maxsat), 100)
-                    m = ms
+                if 'HSL' in label:
+                    m = ms = max(min(max(ms, max(y)), maxsat), 100)
+                elif 'HPL' in label:
+                    m = mp = max(min(max(mp, max(y)), maxsat), 100)
                 else:
-                    mp = max(min(max(mp, max(y)), maxsat), 100)
-                    m = mp
+                    m = mc = max(min(max(mc, max(y)), maxsat), 100)
                 ylim = (0, m)
                 ylocator = ('maxn', 5)
-            ax.scatter(x, y, c=x, cmap=cmap, N=len(x), s=width, linewidths=0)
+            ax.scatter(x, y, c=x, cmap=cmap, s=width, linewidths=0)
             ax.format(title=label, ylim=ylim, ylocator=ylocator)
 
     # Formatting
@@ -396,7 +318,7 @@ def show_channels(
     return fig, axs
 
 
-def show_colorspaces(*, luminance=None, saturation=None, hue=None, axwidth=2):
+def show_colorspaces(*, luminance=None, saturation=None, hue=None, refwidth=2):
     """
     Generate hue-saturation, hue-luminance, and luminance-saturation
     cross-sections for the HCL, HSL, and HPL colorspaces.
@@ -412,7 +334,7 @@ def show_colorspaces(*, luminance=None, saturation=None, hue=None, axwidth=2):
     hue : float, optional
         If passed, luminance-saturation cross-sections
         are drawn for this hue. Must be between ``0`` and ``360``.
-    axwidth : str or float, optional
+    refwidth : str or float, optional
         Average width of each subplot. Units are interpreted by
         `~proplot.utils.units`.
 
@@ -420,6 +342,11 @@ def show_colorspaces(*, luminance=None, saturation=None, hue=None, axwidth=2):
     -------
     `~proplot.figure.Figure`
         The figure.
+
+    See also
+    --------
+    show_cmaps
+    show_channels
     """
     # Get colorspace properties
     hues = np.linspace(0, 360, 361)
@@ -458,9 +385,7 @@ def show_colorspaces(*, luminance=None, saturation=None, hue=None, axwidth=2):
 
     # Make figure, with black indicating invalid values
     # Note we invert the x-y ordering for imshow
-    fig, axs = ui.subplots(
-        ncols=3, share=0, axwidth=axwidth, aspect=1, axpad=0.05
-    )
+    fig, axs = ui.subplots(ncols=3, refwidth=refwidth, share=False, innerpad=0.5)
     for ax, space in zip(axs, ('hcl', 'hsl', 'hpl')):
         rgba = np.ones((*hsl.shape[:2][::-1], 4))  # RGBA
         for j in range(hsl.shape[0]):
@@ -480,13 +405,230 @@ def show_colorspaces(*, luminance=None, saturation=None, hue=None, axwidth=2):
     return fig, axs
 
 
-def _color_filter(hcl, ihue, nhues, minsat):
+@warnings._rename_kwargs('0.8', categories='include')
+def _draw_bars(
+    cmaps, *, source, unknown='User', include=None, ignore=None,
+    length=4.0, width=0.2, N=None
+):
+    """
+    Draw colorbars for "colormaps" and "color cycles". This is called by
+    `show_cycles` and `show_cmaps`.
+    """
+    # Translate local names into database of colormaps
+    # NOTE: Custom cmap database raises nice error if colormap name is unknown
+    i = 1
+    database = pcolors.ColormapDatabase({})  # subset to be drawn
+    for cmap in cmaps:
+        if isinstance(cmap, cycler.Cycler):
+            name = getattr(cmap, 'name', '_no_name')
+            cmap = pcolors.DiscreteColormap(cmap.by_key()['color'], name)
+        elif isinstance(cmap, (list, tuple)):
+            name = '_no_name'
+            cmap = pcolors.DiscreteColormap(cmap, name)
+        elif isinstance(cmap, mcolors.Colormap):
+            name = cmap.name
+        elif isinstance(cmap, str):
+            name = cmap
+            cmap = pcolors._cmap_database[cmap]
+        else:
+            raise ValueError(f'Invalid colormap or cycle type {cmap!r}.')
+        name = _not_none(name, '_no_name')
+        if name in database:
+            name = f'{name}_{i}'  # e.g. _no_name_2
+            i += 1
+        if name.lower()[-2:] == '_r':
+            name = name[:-2]
+        if name.lower()[-2:] == '_s':
+            name = name[:-2]
+        database[name] = cmap
+
+    # Categorize the input names
+    cmapdict = {}
+    names_all = list(map(str.lower, database.keys()))
+    names_known = list(map(str.lower, sum(map(list, source.values()), [])))
+    names_unknown = tuple(name for name in names_all if name not in names_known)
+    if unknown and names_unknown:
+        cmapdict[unknown] = names_unknown
+    for cat, names in source.items():
+        names_cat = [name for name in names if name.lower() in names_all]
+        if names_cat:
+            cmapdict[cat] = names_cat
+
+    # Filter out certain categories
+    options = set(map(str.lower, source))
+    if ignore is None:
+        ignore = ('matlab', 'gnuplot', 'gist', 'other')
+    if isinstance(include, str):
+        include = (include,)
+    if isinstance(ignore, str):
+        ignore = (ignore,)
+    if include is None:
+        include = options - set(map(str.lower, ignore))
+    else:
+        include = set(map(str.lower, include))
+    if any(cat not in options and cat != unknown for cat in include):
+        raise ValueError(
+            f'Invalid categories {include!r}. Options are: '
+            + ', '.join(map(repr, source)) + '.'
+        )
+    for cat in tuple(cmapdict):
+        if cat.lower() not in include and cat != unknown:
+            cmapdict.pop(cat)
+
+    # Draw figure
+    # Allocate two colorbar widths for each title of sections
+    naxs = 2 * len(cmapdict) + sum(map(len, cmapdict.values()))
+    fig, axs = ui.subplots(
+        nrows=naxs, refwidth=length, refheight=width,
+        share=False, top='-1em', hspace='2pt',
+    )
+    iax = -1
+    nheads = nbars = 0  # for deciding which axes to plot in
+    for cat, names in cmapdict.items():
+        nheads += 1
+        for imap, name in enumerate(names):
+            iax += 1
+            if imap + nheads + nbars > naxs:
+                break
+            if imap == 0:  # allocate this axes for title
+                iax += 2
+                for ax in axs[iax - 2:iax]:
+                    ax.set_visible(False)
+            ax = axs[iax]
+            cmap = database[name]
+            if N is not None:
+                cmap = cmap.copy(N=N)
+            ax.colorbar(
+                cmap, loc='fill',
+                orientation='horizontal', locator='null', linewidth=0
+            )
+            ax.text(
+                0 - (rc['axes.labelpad'] / 72) / length, 0.45, name,
+                ha='right', va='center', transform='axes',
+            )
+            if imap == 0:
+                ax.set_title(cat, weight='bold')
+        nbars += len(names)
+
+    return fig, axs
+
+
+@_snippet_manager
+def show_cmaps(*args, **kwargs):
+    """
+    Generate a table of the registered colormaps or the input colormaps
+    categorized by source. Adapted from `this example \
+<http://matplotlib.org/stable/gallery/color/colormap_reference.html>`__.
+
+    Parameters
+    ----------
+    *args : colormap-spec, optional
+        Colormap names or objects.
+    N : int, optional
+        The number of levels in each colorbar. Default is
+        :rc:`image.lut`.
+    unknown : str, optional
+        Category name for colormaps that are unknown to ProPlot. The
+        default is ``'User'``. Set this to ``False`` to hide
+        unknown colormaps.
+    include : str or list of str, optional
+        Category names to be shown in the table. Use this to limit the table
+        to a subset of categories. Valid categories are %(cmap.categories)s.
+    ignore : str or list of str, optional
+        Used only if `include` was not passed. Category names to be removed from the
+        table. Default is ``'MATLAB'``, ``'GNUplot'``, ``'GIST'``, and ``'Other'``.
+        Use of these colormaps is discouraged, because they contain non-uniform color
+        transitions (see the :ref:`user guide <ug_perceptual>`).
+    %(show.colorbars)s
+
+    Returns
+    -------
+    `~proplot.figure.Figure`
+        The figure.
+
+    See also
+    --------
+    show_colorspaces
+    show_channels
+    show_cycles
+    show_colors
+    show_fonts
+    """
+    # Get the list of colormaps
+    # TODO: Filter out colormaps ending with '_copy' and '_r'?
+    if args:
+        cmaps = [constructor.Colormap(cmap) for cmap in args]
+        ignore = ()
+    else:
+        cmaps = [
+            name for name, cmap in pcolors._cmap_database.items()
+            if isinstance(cmap, pcolors.ContinuousColormap)
+        ]
+        ignore = None
+
+    # Return figure of colorbars
+    kwargs.setdefault('source', CMAPS_TABLE)
+    kwargs.setdefault('ignore', ignore)
+    return _draw_bars(cmaps, **kwargs)
+
+
+@_snippet_manager
+def show_cycles(*args, **kwargs):
+    """
+    Generate a table of registered color cycles or the input color cycles
+    categorized by source. Adapted from `this example \
+<http://matplotlib.org/stable/gallery/color/colormap_reference.html>`__.
+
+    Parameters
+    ----------
+    *args : colormap-spec, optional
+        Cycle names or objects.
+    unknown : str, optional
+        Category name for cycles that are unknown to ProPlot. The default
+        is ``'User'``. Set this to ``False`` to hide unknown colormaps.
+    include : str or list of str, optional
+        Category names to be shown in the table. Use this to limit the table
+        to a subset of categories. Valid categories are %(cycle.categories)s.
+    ignore : str or list of str, optional
+        Used only if `include` was not passed. Category names to be removed from
+        the table. Default is ``'MATLAB'``, ``'GNUplot'``, ``'GIST'``, and ``'Other'``.
+    %(show.colorbars)s
+
+    Returns
+    -------
+    `~proplot.figure.Figure`
+        The figure.
+
+    See also
+    --------
+    show_cmaps
+    show_colors
+    show_fonts
+    """
+    # Get the list of cycles
+    if args:
+        cycles = [constructor.Cycle(cmap, to_listed=True) for cmap in args]
+        ignore = ()
+    else:
+        cycles = [
+            name for name, cmap in pcolors._cmap_database.items()
+            if isinstance(cmap, pcolors.DiscreteColormap)
+        ]
+        ignore = None
+
+    # Return figure of colorbars
+    kwargs.setdefault('source', CYCLES_TABLE)
+    kwargs.setdefault('ignore', ignore)
+    return _draw_bars(cycles, **kwargs)
+
+
+def _filter_colors(hcl, ihue, nhues, minsat):
     """
     Filter colors into categories.
 
     Parameters
     ----------
-    hcl : (name, hcl)
+    hcl : tuple
         The data.
     ihue : int
         The hue column.
@@ -505,8 +647,10 @@ def _color_filter(hcl, ihue, nhues, minsat):
     return not gray and color
 
 
-@docstring.add_snippets
-def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
+@_snippet_manager
+def show_colors(
+    *, nhues=17, minsat=10, unknown='User', include=None, ignore=None
+):
     """
     Generate tables of the registered color names. Adapted from
     `this example <https://matplotlib.org/examples/color/named_colors.html>`__.
@@ -519,15 +663,15 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
     minsat : float, optional
         The threshold saturation, between ``0`` and ``100``, for designating
         "gray colors" in the color table.
-    categories : list of str, optional
-        Category names to be shown in the table.
-        By default, every category is shown except for CSS colors.
-
-        Valid categories are %(color.categories)s.
     unknown : str, optional
-        Category name for color names that are unknown to ProPlot. The
-        default is ``'User'``. Set this to ``False`` to hide
-        unknown color names.
+        Category name for color names that are unknown to ProPlot. The default
+        is ``'User'``. Set this to ``False`` to hide unknown color names.
+    include : str or list of str, optional
+        Category names to be shown in the table. Use this to limti the table
+        to a subset of categories. Valid categories are %(color.categories)s.
+    ignore : str or list of str, optional
+        Used only if `include` was not passed. Category names to be removed
+        from the colormap table. Default is ``'CSS4'``.
 
     Returns
     -------
@@ -536,22 +680,27 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
     """
     # Tables of known colors to be plotted
     colordict = {}
-    if isinstance(categories, str):
-        categories = [categories]
-    if categories is None:
-        categories = ['base', 'opencolor', 'xkcd']  # preserve order
-    for cat in categories:
+    if ignore is None:
+        ignore = 'css4'
+    if isinstance(include, str):
+        include = (include.lower(),)
+    if isinstance(ignore, str):
+        ignore = (ignore.lower(),)
+    if include is None:
+        include = COLORS_TABLE.keys()
+        include -= set(map(str.lower, ignore))
+    for cat in sorted(include):
         if cat not in COLORS_TABLE:
             raise ValueError(
-                f'Invalid categories {categories!r}. Options are: '
+                f'Invalid categories {include!r}. Options are: '
                 + ', '.join(map(repr, COLORS_TABLE)) + '.'
             )
-        colordict[cat] = COLORS_TABLE[cat]
+        colordict[cat] = list(COLORS_TABLE[cat])  # copy the names
 
     # Add "unknown" colors
     if unknown:
         unknown_colors = [
-            color for color in map(repr, mcolors.colorConverter.colors)
+            color for color in map(repr, pcolors._color_database)
             if 'xkcd:' not in color and 'tableau:' not in color
             and not any(color in list_ for list_ in COLORS_TABLE)
         ]
@@ -563,7 +712,7 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
     # colors, so just reshape them into grids. For other colors, we group
     # them by hue in descending order of luminance.
     namess = {}
-    for cat in categories:
+    for cat in sorted(include):
         if cat == 'base':
             names = np.asarray(colordict[cat]).reshape((2, 8)).T
         elif cat == 'opencolor':
@@ -575,7 +724,7 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
                 sorted(
                     [
                         pair for pair in hclpairs
-                        if _color_filter(pair[1], ihue, nhues, minsat)
+                        if _filter_colors(pair[1], ihue, nhues, minsat)
                     ],
                     key=lambda x: x[1][2]  # sort by luminance
                 )
@@ -595,17 +744,15 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
     # of rows, times the aspect ratio of the slot for each swatch-name
     # pair, which we set to 5.
     shape = tuple(namess.values())[0].shape  # sample *first* group
-    width = 6.5
-    margin = 0.1
-    ncols_max = max(names.shape[0] for names in namess.values())
-    aspect_axes = (width * 72) / (10 * shape[1])  # points
-    height_ratios = tuple(names.shape[1] for names in namess.values())
+    figwidth = 6.5
+    refaspect = (figwidth * 72) / (10 * shape[1])  # points
+    maxcols = max(names.shape[0] for names in namess.values())
+    hratios = tuple(names.shape[1] for names in namess.values())
     fig, axs = ui.subplots(
-        nrows=len(categories),
-        width=width,
-        aspect=aspect_axes,
-        height_ratios=height_ratios,
-        left=margin, right=margin, bottom=margin,
+        nrows=len(include),
+        hratios=hratios,
+        figwidth=figwidth,
+        refaspect=refaspect,
     )
     title_dict = {
         'css4': 'CSS4 colors',
@@ -618,7 +765,7 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
         ax.format(
             title=title_dict.get(cat, cat),
             titleweight='bold',
-            xlim=(0, ncols_max - 1),
+            xlim=(0, maxcols - 1),
             ylim=(0, names.shape[1]),
             grid=False, yloc='neither', xloc='neither',
             alpha=0,
@@ -633,7 +780,7 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
                 if not name:
                     continue
                 y = nrows - row - 1  # start at top
-                x1 = col * (ncols_max - 1) / ncols  # e.g. idx 3 --> idx 7
+                x1 = col * (maxcols - 1) / ncols  # e.g. idx 3 --> idx 7
                 x2 = x1 + swatch  # portion of column
                 xtext = x1 + 1.1 * swatch
                 ax.text(
@@ -650,94 +797,6 @@ def show_colors(*, nhues=17, minsat=10, categories=None, unknown='User'):
     return fig, axs
 
 
-@docstring.add_snippets
-def show_cmaps(*args, **kwargs):
-    """
-    Generate a table of the registered colormaps or the input colormaps
-    categorized by source. Adapted from `this example \
-<http://matplotlib.org/examples/color/colormaps_reference.html>`__.
-
-    Parameters
-    ----------
-    *args : colormap-spec, optional
-        Colormap names or objects.
-    N : int, optional
-        The number of levels in each colorbar. Default is
-        :rc:`image.lut`.
-    unknown : str, optional
-        Category name for colormaps that are unknown to ProPlot. The
-        default is ``'User'``. Set this to ``False`` to hide
-        unknown colormaps.
-    categories : list of str, optional
-        Category names to be shown in the table.  By default, all categories
-        are shown except for ``'MATLAB'``, ``'GNUplot'``, ``'GIST'``, and
-        ``'Other'``. Use of these colormaps is discouraged, because they
-        contain a variety of non-uniform colormaps (see
-        :ref:`perceptually uniform colormaps <ug_perceptual>` for details).
-
-        Valid categories are %(cmap.categories)s.
-    %(show.colorbars)s
-
-    Returns
-    -------
-    `~proplot.figure.Figure`
-        The figure.
-    """
-    # Get the list of colormaps
-    if args:
-        cmaps = [constructor.Colormap(cmap) for cmap in args]
-    else:
-        cmaps = [
-            name for name in pcolors._cmap_database.keys() if
-            isinstance(pcolors._cmap_database[name], pcolors.LinearSegmentedColormap)
-        ]
-
-    # Return figure of colorbars
-    kwargs.setdefault('source', CMAPS_TABLE)
-    return _draw_bars(cmaps, **kwargs)
-
-
-@docstring.add_snippets
-def show_cycles(*args, **kwargs):
-    """
-    Generate a table of registered color cycles or the input color cycles
-    categorized by source. Adapted from `this example \
-<http://matplotlib.org/examples/color/colormaps_reference.html>`__.
-
-    Parameters
-    ----------
-    *args : colormap-spec, optional
-        Cycle names or objects.
-    unknown : str, optional
-        Category name for cycles that are unknown to ProPlot. The
-        default is ``'User'``. Set this to ``False`` to hide
-        unknown colormaps.
-    categories : list of str, optional
-        Category names to be shown in the table.
-        By default, all categories are shown.
-
-        Valid categories are %(cycle.categories)s.
-    %(show.colorbars)s
-
-    Returns
-    -------
-    `~proplot.figure.Figure`
-        The figure.
-    """
-    # Get the list of cycles
-    if args:
-        cycles = [constructor.Cycle(cmap, to_listed=True) for cmap in args]
-    else:
-        cycles = [
-            name for name in pcolors._cmap_database.keys() if
-            isinstance(pcolors._cmap_database[name], pcolors.ListedColormap)
-        ]
-
-    # Return figure of colorbars
-    kwargs.setdefault('source', CYCLES_TABLE)
-    return _draw_bars(cycles, **kwargs)
-
-
 def show_fonts(
     *args, family=None, text=None,
     size=12, weight='normal', style='normal', stretch='normal',
@@ -749,17 +808,17 @@ def show_fonts(
     Parameters
     ----------
     *args
-        The font name(s). If none are provided and the `family` keyword
-        argument was not provided, the *available* :rcraw:`font.sans-serif`
-        fonts and the fonts in your ``.proplot/fonts`` folder are shown.
-    family : {'serif', 'sans-serif', 'monospace', 'cursive', 'fantasy', \
-'tex-gyre'}, optional
+        The font name(s). If none are provided and the `family` keyword argument
+        was not provided, the *available* :rcraw:`font.sans-serif` fonts and the
+        user fonts added to `~proplot.config.Configurator.user_folder` are shown.
+    family \
+: {'serif', 'sans-serif', 'monospace', 'cursive', 'fantasy', 'tex-gyre'}, optional
         If provided, the *available* fonts in the corresponding families
         are shown. The fonts belonging to these families are listed under the
         :rcraw:`font.serif`, :rcraw:`font.sans-serif`, :rcraw:`font.monospace`,
-        :rcraw:`font.cursive`, and :rcraw:`font.fantasy` settings. The special
-        family ``'tex-gyre'`` draws the `TeX Gyre \
-<http://www.gust.org.pl/projects/e-foundry/tex-gyre>`__ fonts.
+        :rcraw:`font.cursive`, and :rcraw:`font.fantasy` settings. The
+        family ``'tex-gyre'`` draws the
+        `TeX Gyre <http://www.gust.org.pl/projects/e-foundry/tex-gyre>`__ fonts.
     text : str, optional
         The sample text. The default sample text includes the Latin letters,
         Greek letters, Arabic numerals, and some simple mathematical symbols.
@@ -771,23 +830,26 @@ def show_fonts(
         The font style.
     stretch : stretch-spec, optional
         The font stretch.
+
+    See also
+    --------
+    show_cmaps
+    show_cycles
+    show_colors
     """
     if not args and family is None:
-        # User fonts and sans-serif fonts. Note all proplot sans-serif fonts
-        # are added to 'font.sans-serif' by default
+        # User fonts and sans-serif fonts. Note all proplot sans-serif
+        # fonts are added to 'font.sans-serif' by default
         args = sorted({
             font.name for font in mfonts.fontManager.ttflist
             if font.name in rc['font.sans-serif']
-            or _get_data_paths('fonts')[1] == os.path.dirname(font.fname)
+            or _get_data_folders('fonts')[1] == os.path.dirname(font.fname)
         })
     elif family is not None:
-        options = (
-            'serif', 'sans-serif', 'monospace', 'cursive', 'fantasy',
-            'tex-gyre',
-        )
+        options = ('serif', 'sans-serif', 'monospace', 'cursive', 'fantasy', 'tex-gyre')
         if family not in options:
             raise ValueError(
-                f'Invalid family {family!r}. Options are: '
+                f'Invalid font family {family!r}. Options are: '
                 + ', '.join(map(repr, options)) + '.'
             )
         if family == 'tex-gyre':
@@ -827,8 +889,8 @@ def show_fonts(
     # Create figure
     fig, axs = ui.subplots(
         ncols=1, nrows=len(args), space=0,
-        axwidth=4.5, axheight=1.2 * (text.count('\n') + 2.5) * size / 72,
-        fallback_to_cm=False
+        refwidth=4.5, refheight=1.2 * (text.count('\n') + 2.5) * size / 72,
+        mathtext_fallback=False
     )
     axs.format(
         xloc='neither', yloc='neither',
